@@ -63,6 +63,8 @@ static char *info[] = {
   "     Set -Va=0, if Va=0 is assumed; otherwise Va is always fitted.",
   " -Vd=<filename>",
   "     Parametric K1/k2 image (apparent pH2O) is saved.",
+  " -wss=<filename>",
+  "     Weighted sum-of-squares are written in specified image file.",
   " -thr=<threshold%>",
   "     Pixels with AUC less than (threshold/100 x max AUC) are set to zero.",
   "     Default is 5%.",
@@ -131,7 +133,7 @@ int main(int argc, char *argv[])
   int     fi, pi, yi, xi, ret;
   int     weight=0, dataNr=0, param_filt=0;
   char    inpfile[FILENAME_MAX], petfile[FILENAME_MAX], k1file[FILENAME_MAX];
-  char    k2file[FILENAME_MAX], vafile[FILENAME_MAX], dvfile[FILENAME_MAX];
+  char    k2file[FILENAME_MAX], vafile[FILENAME_MAX], dvfile[FILENAME_MAX], wssfile[FILENAME_MAX];
   char   *cptr, tmp[FILENAME_MAX+1];
   float   calcThreshold=0.05;
   double  upperLimit=-1.0;
@@ -142,7 +144,7 @@ int main(int argc, char *argv[])
   int     k1_nn_constraint=0;
   int     per_dl=0;
   DFT     tac;
-  IMG     img, k1img, k2img, vaimg, dvimg;
+  IMG     img, k1img, k2img, vaimg, dvimg, wssimg;
   double *cp, *cpi, *ct, *cti, Va;
   /* nnls */
   int     nnls_n, nnls_m, nnls_index[NNLS_N];
@@ -155,7 +157,7 @@ int main(int argc, char *argv[])
    *  Get arguments
    */
   if(argc==1) {tpcPrintUsage(argv[0], info, stderr); return(1);}
-  inpfile[0]=petfile[0]=k1file[0]=k2file[0]=vafile[0]=dvfile[0]=(char)0;
+  inpfile[0]=petfile[0]=k1file[0]=k2file[0]=vafile[0]=dvfile[0]=wssfile[0]=(char)0;
   /* Get options */
   for(ai=1; ai<argc; ai++) if(*argv[ai]=='-') {
     if(tpcProcessStdOptions(argv[ai], &help, &version, &verbose)==0) continue;
@@ -192,6 +194,8 @@ int main(int argc, char *argv[])
       upperLimit=atof_dpi(cptr+4); if(upperLimit>0.0) continue;
     } else if(strncasecmp(cptr, "END=", 4)==0) {
       fittime=atof_dpi(cptr+4)/60.; if(fittime>0.0) continue;
+    } else if(strncasecmp(cptr, "WSS=", 4)==0) {
+      strlcpy(wssfile, cptr+4, FILENAME_MAX); if(strlen(wssfile)>0) continue;
     }
     fprintf(stderr, "Error: invalid option '%s'.\n", argv[ai]);
     return(1);
@@ -229,10 +233,11 @@ int main(int argc, char *argv[])
     printf("inpfile := %s\n", inpfile);
     printf("petfile := %s\n", petfile);
     printf("k1file := %s\n", k1file);
-    printf("k2file := %s\n", k2file);
+    if(k2file[0]) printf("k2file := %s\n", k2file);
     printf("fitVa := %d\n", fitVa);
-    printf("vafile := %s\n", vafile);
-    printf("dvfile := %s\n", dvfile);
+    if(vafile[0]) printf("vafile := %s\n", vafile);
+    if(dvfile[0]) printf("dvfile := %s\n", dvfile);
+    if(wssfile[0]) printf("wssfile := %s\n", wssfile);
     printf("calcThreshold := %g\n", calcThreshold);
     printf("max := %f\n", upperLimit);
     printf("fittime := %g [min]\n", fittime);
@@ -282,8 +287,7 @@ int main(int argc, char *argv[])
     imgEmpty(&img); dftEmpty(&tac); return(4);
   }
   if(verbose>1)
-    fprintf(stdout, "threshold_cutoff_nr := %lld / %lld\n",
-            tn, (long long)img.dimx*img.dimy*img.dimz); 
+    fprintf(stdout, "threshold_cutoff_nr := %lld / %lld\n", tn, (long long)img.dimx*img.dimy*img.dimz); 
 
 
   /* Allocate memory for tissue TAC and integral */
@@ -302,7 +306,7 @@ int main(int argc, char *argv[])
    *  Allocate result images and fill the header info
    */
   if(verbose>1) printf("allocating memory for parametric images\n");
-  imgInit(&k1img); imgInit(&k2img); imgInit(&dvimg); imgInit(&vaimg);
+  imgInit(&k1img); imgInit(&k2img); imgInit(&dvimg); imgInit(&vaimg); imgInit(&wssimg);
   /* K1 image */
   ret=imgAllocateWithHeader(&k1img, img.dimz, img.dimy, img.dimx, 1, &img);
   if(ret==0) {
@@ -323,10 +327,14 @@ int main(int argc, char *argv[])
     ret=imgAllocateWithHeader(&vaimg, img.dimz, img.dimy, img.dimx, 1, &k1img);
     if(ret==0) vaimg.unit=IMGUNIT_ML_PER_ML;
   }
+  if(ret==0 && wssfile[0]) {
+    ret=imgAllocateWithHeader(&wssimg, img.dimz, img.dimy, img.dimx, 1, &k1img);
+    if(ret==0) wssimg.unit=IMGUNIT_UNKNOWN;
+  }
   if(ret) {
     fprintf(stderr, "Error: cannot setup memory for parametric image.\n");
     imgEmpty(&img); dftEmpty(&tac);
-    imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg);
+    imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg); imgEmpty(&wssimg);
     return(6);
   }
 
@@ -339,7 +347,7 @@ int main(int argc, char *argv[])
   if(nnls_mat==NULL) {
     fprintf(stderr, "Error: cannot allocate memory for NNLS.\n");
     imgEmpty(&img); dftEmpty(&tac);
-    imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg);
+    imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg); imgEmpty(&wssimg);
     return(7);
   }
   dptr=nnls_mat;
@@ -461,6 +469,17 @@ int main(int argc, char *argv[])
           nr_of_negative_k1++;
         }
 
+        /* Calculate Sum-of-Squares, if user wants to save it */
+        if(wssfile[0]) {
+          double wss=0.0;
+          for(int m=0; m<nnls_m; m++) {
+            double f=0.0;
+            for(int n=0; n<nnls_n; n++) f+=nnls_x[n]*nnls_a[n][m];
+            f-=nnls_b[m]; wss+=f*f;
+          }
+          wssimg.m[pi][yi][xi][0]=wss;
+        }
+
         /*
          *  Estimate K1/k2, if necessary
          */
@@ -504,7 +523,7 @@ int main(int argc, char *argv[])
   } /* next plane */
   if(verbose>0) fprintf(stdout, "done.\n");
 
-  /* No need for dynamic image, NNLS matrix or curves anymore */
+  /* No need for dynamic image, NNLS matrix or curves any more */
   free(nnls_mat); imgEmpty(&img); dftEmpty(&tac);
 
   /* Tell user how many negative k1 values we got 
@@ -573,7 +592,7 @@ int main(int argc, char *argv[])
   if(ret) {
     fprintf(stderr, "Error: %s\n", k1img.statmsg);
     if(verbose>1) printf("ret := %d\n", ret);
-    imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg);
+    imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg); imgEmpty(&wssimg);
     return(13);
   }
   if(verbose>0) fprintf(stdout, "Flow image %s saved.\n", k1file);
@@ -582,7 +601,7 @@ int main(int argc, char *argv[])
     ret=imgWrite(k2file, &k2img);
     if(ret) {
       fprintf(stderr, "Error: %s\n", k2img.statmsg);
-      imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg);
+      imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg); imgEmpty(&wssimg);
       return(14);
     }
     if(verbose>0) fprintf(stdout, "k2 image %s saved.\n", k2file);
@@ -592,7 +611,7 @@ int main(int argc, char *argv[])
     ret=imgWrite(dvfile, &dvimg);
     if(ret) {
       fprintf(stderr, "Error: %s\n", dvimg.statmsg);
-      imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg);
+      imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg); imgEmpty(&wssimg);
       return(15);
     }
     if(verbose>0) fprintf(stdout, "DV image %s saved.\n", dvfile);
@@ -602,14 +621,24 @@ int main(int argc, char *argv[])
     ret=imgWrite(vafile, &vaimg);
     if(ret) {
       fprintf(stderr, "Error: %s\n", vaimg.statmsg);
-      imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg);
+      imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg); imgEmpty(&wssimg);
       return(16);
     }
     if(verbose>0) fprintf(stdout, "Va image %s saved.\n", vafile);
   }
+  /* WSS */
+  if(wssfile[0]) {
+    ret=imgWrite(wssfile, &wssimg);
+    if(ret) {
+      fprintf(stderr, "Error: %s\n", wssimg.statmsg);
+      imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg); imgEmpty(&wssimg);
+      return(16);
+    }
+    if(verbose>0) fprintf(stdout, "WSS image %s saved.\n", wssfile);
+  }
 
   if(verbose>2) printf("before quitting, free memory\n");
-  imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg);
+  imgEmpty(&k1img); imgEmpty(&k2img); imgEmpty(&dvimg); imgEmpty(&vaimg); imgEmpty(&wssimg);
   fflush(stdout);
 
   return(0);
