@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_imgflow
-#: Date       : 2018-03-22
+#: Date       : 2022-08-09
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -30,6 +30,12 @@ if [ ! -f blood.dat ] || [ ! -f frames.dat ]; then
   exit 1
 fi
 
+if [ ! -f blood_delayed.dat ]; then
+  tactime -nogap blood.dat +5 blood_delayed.dat
+  if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+fi
+
+
 if [ ! -f lowmid.v ] || [ ! -f correct_lowmid_flow.v ]; then
   printf "\n Simulate low-to-mid range flow image with Vb=3 \n"
   b2t_h2o --silent      -voiname="f1" blood.dat   1 0.8 1 3 100 temp.dft
@@ -515,6 +521,40 @@ printf "\n passed. \n\n"
 
 printf "\n===================================================================\n"
 
+printf "\n 1.7.0 \n"
+printf " Test case: Option -wss. \n"
+printf " Expected result 1: WSS data is saved in given file that is readable with other SW. \n"
+printf " Expected result 2: Delayed BTAC should lead to higher WSS. \n\n"
+
+rm -f flow.v wss1.v wss2.v dif.v dif.txt
+
+$PROGRAM -thr=0 -wss=wss1.v blood.dat lowmid.v 99999 flow.v
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+
+img2tif -rb wss1.v wss1.tif
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+$PROGRAM -thr=0 -wss=wss2.v blood_delayed.dat lowmid.v 99999 flow.v
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+
+imgcalc wss2.v - wss1.v dif.v
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+imgmax -both dif.v > dif.txt
+printf "\n ok \n"
+iftisval -gt dif.txt max 0
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+iftisval -gt dif.txt min 0
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+
+
+printf "\n===================================================================\n"
 
 
 
