@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_fit_ppf
-#: Date       : 2020-02-11
+#: Date       : 2022-03-29
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -202,7 +202,7 @@ fi
 if [ ! -f data5_weights.dat ] ; then
   fit2dat -x=0.5,1.5,2.5,3.5,4.5,5.5,7,9 orig_ppf.fit data5_weights.dat
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
-  dftweigh -wf data5_weights.dat
+  tacweigh -wf data5_weights.dat
   if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
 fi
 
