@@ -89,13 +89,6 @@ int dftRead(
     }
     // if not ok, then just drop through with plain format
     type=DFT_FORMAT_PLAIN;
-#if(0)
-    if(ret!=0) {strcpy(dfterrmsg, "cannot read file"); return ret;}
-    ret=csv2dft(&csv, data); csvEmpty(&csv);
-    if(ret!=0) {strcpy(dfterrmsg, "invalid CSV format"); return ret;}
-    if(strlen(data->studynr)==0) studynr_from_fname(filename, data->studynr);
-    return(0);
-#endif
   }
 
   /* Try to read supported TAC formats, not the others */
@@ -215,11 +208,7 @@ int dftRead(
       lptr=line;
       /* Check for comment line */
       if(line[0]=='#') { /* Read comment only if there is space left */
-#if(1)
         strlcat(data->comments, line, _DFT_COMMENT_LEN);
-#else
-        if(strlen(data->comments)+strlen(line)<_DFT_COMMENT_LEN) strcat(data->comments, line);
-#endif
         continue;
       }
       cptr=strchr(line, '#'); if(cptr!=NULL) *cptr=(char)0;
@@ -500,22 +489,6 @@ int dftFormat(
     if(format!=DFT_FORMAT_UNKNOWN) return(format);
   }
 
-#if(0)
-  if(fncasematch(fname, "*.csv")==1) {
-    /* If ';' is found, then international format, otherwise UK format */
-    while((c=fgetc(fp))!=EOF)
-      if(c==';') {fclose(fp); return DFT_FORMAT_CSV_INT;}
-    fclose(fp); return DFT_FORMAT_CSV_UK;
-  }
-  if(fncasematch(fname, "*.tsv")==1) {
-    /* If ',' is found, then international format, otherwise UK format */
-    while((c=fgetc(fp))!=EOF)
-      if(c==',') {fclose(fp); return DFT_FORMAT_CSV_INT;}
-    fclose(fp); return DFT_FORMAT_CSV_UK;
-  }
-  fclose(fp);
-#endif
-
   return DFT_FORMAT_PLAIN;
 }
 /*****************************************************************************/
@@ -560,6 +533,7 @@ int dftType(FILE *fp)
 /*****************************************************************************/
 /** Prints to stdout the contents of DFT data structure.
     Mainly for testing purposes.
+    @sa dftWrite
  */
 void dftPrint(DFT *data)
 {
@@ -614,11 +588,11 @@ void dftPrint(DFT *data)
 
     The file format specified in data is applied.
     Number of decimals can be determined by changing global variable DFT_NR_OF_DECIMALS.
-    @sa dftRead
+    @sa dftRead, resWrite
     @return Returns 0 when successful, in case of error sets dfterrmsg.
  */
 int dftWrite(
-  /** Pointer to DFT struct which contents are to be written. */
+  /** Pointer to DFT structure which contents are to be written. */
   DFT *data,
   /** File name where DFT contents are written. If file exists, original file
       is renamed to a backup file. */
@@ -634,9 +608,7 @@ int dftWrite(
 
   /* If format if DFT_FORMAT_HTML or extension is *.HTM(L),
      write in HTML format */
-  if(data->_type==DFT_FORMAT_HTML || fncasematch(filename, "*.htm")==1 ||
-     fncasematch(filename, "*.html")==1)
-  {
+  if(data->_type==DFT_FORMAT_HTML || fncasematch(filename, "*.htm")==1 || fncasematch(filename, "*.html")==1) {
     return(dftWriteHTML(data, filename, 1));
   }
 
@@ -780,7 +752,7 @@ int dftWrite(
     If file exists, a backup file (+BACKUP_EXTENSION) is written also.
     If "stdout" is given as filename, output is directed to stdout
     In case of an error, description is written in dfterrmsg.
-\return Returns 0 if ok.
+    @return Returns 0 if ok.
 */
 int dftWriteHTML(
   /** Input DFT */
@@ -831,18 +803,27 @@ int dftWriteHTML(
     if(orientation!=2) {
       /* Empty cell and Region names */
       fprintf(fp, "<tr><td> </td>\n");
-      for(ri=0; ri<dft->voiNr; ri++)
-        fprintf(fp, "<th>%s</th>\n", dft->voi[ri].voiname);
+      for(ri=0; ri<dft->voiNr; ri++) {
+        char *senc=strEncodeForXML(dft->voi[ri].voiname);
+        if(senc==NULL) fprintf(fp, "<th>%s</th>\n", dft->voi[ri].voiname);
+        else {fprintf(fp, "<th>%s</th>\n", senc); free(senc);}
+      }
       fprintf(fp, "</tr>\n");
       /* Study number and Hemispheres */
       fprintf(fp, "<tr><th>%s</th>\n", dft->studynr);
-      for(ri=0; ri<dft->voiNr; ri++)
-        fprintf(fp, "<th>%s</th>\n", dft->voi[ri].hemisphere);
+      for(ri=0; ri<dft->voiNr; ri++) {
+        char *senc=strEncodeForXML(dft->voi[ri].hemisphere);
+        if(senc==NULL) fprintf(fp, "<th>%s</th>\n", dft->voi[ri].hemisphere);
+        else {fprintf(fp, "<th>%s</th>\n", senc); free(senc);}
+      }
       fprintf(fp, "</tr>\n");
       /* Unit and Places */
       fprintf(fp, "<tr><th>%s</th>\n", dft->unit);
-      for(ri=0; ri<dft->voiNr; ri++)
-        fprintf(fp, "<th>%s</th>\n", dft->voi[ri].place);
+      for(ri=0; ri<dft->voiNr; ri++) {
+        char *senc=strEncodeForXML(dft->voi[ri].place);
+        if(senc==NULL) fprintf(fp, "<th>%s</th>\n", dft->voi[ri].place);
+        else {fprintf(fp, "<th>%s</th>\n", senc); free(senc);}
+      }
       fprintf(fp, "</tr>\n");
       /* Time unit and Volumes */
       fprintf(fp, "<tr><th>%s</th>\n", petTunit(dft->timeunit));
@@ -879,9 +860,19 @@ int dftWriteHTML(
   } else { /* transposed */
     for(ri=0; ri<dft->voiNr; ri++) {
       if(ri%2) strcpy(tmp, "evenframe"); else strcpy(tmp, "oddframe");
-      /* Region names and volume */
-      fprintf(fp, "<tr class=\"%s\"><th>%s</th><th>%s</th><th>%s</th>\n", tmp,
-        dft->voi[ri].voiname, dft->voi[ri].hemisphere, dft->voi[ri].place);
+      fprintf(fp, "<tr class=\"%s\">", tmp);
+      /* Region names */
+      char *senc;
+      senc=strEncodeForXML(dft->voi[ri].voiname);
+      if(senc==NULL) fprintf(fp, "<th>%s</th>", dft->voi[ri].voiname);
+      else {fprintf(fp, "<th>%s</th>", senc); free(senc);}
+      senc=strEncodeForXML(dft->voi[ri].hemisphere);
+      if(senc==NULL) fprintf(fp, "<th>%s</th>", dft->voi[ri].hemisphere);
+      else {fprintf(fp, "<th>%s</th>", senc); free(senc);}
+      senc=strEncodeForXML(dft->voi[ri].place);
+      if(senc==NULL) fprintf(fp, "<th>%s</th>\n", dft->voi[ri].place);
+      else {fprintf(fp, "<th>%s</th>\n", senc); free(senc);}
+      /* Region volume */
       fprintf(fp, "<td>%g</td>\n", dft->voi[ri].size);
       /* Values */
       for(fi=0; fi<dft->frameNr; fi++) {
@@ -912,7 +903,7 @@ int dftWriteHTML(
 
 /*****************************************************************************/
 /** Write XHTML 1.1 doctype into an opened file pointer.
-\return Returns 0 if successful, non-zero in case of a failure.
+    @return Returns 0 if successful, non-zero in case of a failure.
  */
 int dftWriteXHTML11_doctype(
   FILE *fp
@@ -930,7 +921,7 @@ int dftWriteXHTML11_doctype(
 
 /*****************************************************************************/
 /** Write XHTML 1.1 head for DFT file into an opened file pointer.
-\return Returns 0 if successful, non-zero in case of a failure.
+    @return Returns 0 if successful, non-zero in case of a failure.
  */
 int dftWriteXHTML11_head(
   /** File pointer where to write */
@@ -979,7 +970,7 @@ int dftWriteXHTML11_head(
 
 /*****************************************************************************/
 /** Read certain keys from IFT and set DFT fields accordingly.
-\return Returns the nr of identified keys.
+    @return Returns the nr of identified keys.
  */
 int dft_fill_hdr_from_IFT(
   /** Pointer to allocated DFT struct where information will be written */
