@@ -254,6 +254,7 @@ typedef struct TPCSTATUS {
 extern int strTokenNr(const char *s1, const char *s2);
 extern int strTokenNCpy(const char *s1, const char *s2, int i, char *s3, int count);
 extern int strChrCount(const char *s1, const char *s2);
+extern int strUppercaseCount(const char *s);
 extern void strReplaceChar(char *s, char c1, char c2);
 /////#ifndef HAVE_STRCASESTR
 extern char *strcasestr(const char *haystack, const char *needle);
@@ -287,6 +288,8 @@ extern char *strncatIntZ(char *str1, const int n, const int maxn, size_t count);
 extern int strIsSpaceOnly(char *s);
 extern char *strdelstr(char *s1, const char *s2);
 extern char *strTrimLeft(char *s, const size_t t);
+extern char *strEncodeForXML(const char *s);
+extern void strCleanForXML(char *s);
 /*****************************************************************************/
 
 /*****************************************************************************/
