@@ -375,10 +375,11 @@ int imgReadNiftiFrame(
     printf("no SIF found for %s\n", basefile); fflush(stdout);}
 
   /* Open image datafile */
-  if(verbose>2) {
-    fprintf(stdout, "reading image data %s\n", datfile); fflush(stdout);}
-  imgSetStatus(img, STATUS_NOIMGDATA);
-  if((fp=fopen(datfile, "rb")) == NULL) return STATUS_NOIMGDATA;
+  if(verbose>2) {fprintf(stdout, "reading image data %s\n", datfile); fflush(stdout);}
+  if((fp=fopen(datfile, "rb")) == NULL) {
+    imgSetStatus(img, STATUS_NOIMGDATAFILE);
+    return STATUS_NOIMGDATAFILE;
+  }
 
   /* Allocate memory for one image frame */
   imgSetStatus(img, STATUS_NOMEMORY);
@@ -399,6 +400,25 @@ int imgReadNiftiFrame(
     return STATUS_UNSUPPORTED;
   }
 
+  /* Check for invalid pixel values and set to zero.
+     SPM can write lots of NaNs on image borders.
+     Remove this later, if/when all image processing functions support NaN and Inf. */
+  if(1) {
+    long long int goodNr=0;
+    fptr=fdata;
+    for(int zi=0; zi<img->dimz; zi++)
+      for(int yi=0; yi<img->dimy; yi++)
+        for(int xi=0; xi<img->dimx; xi++) {
+          if(isfinite(*fptr)) goodNr++; else *fptr=0.0;
+          fptr++;
+        }
+    if(goodNr==0) {
+      free(fdata);
+      imgSetStatus(img, STATUS_NOIMGDATA);
+      return STATUS_NOIMGDATA;
+    }
+  }
+
   /* Copy pixel values to IMG */
   fptr=fdata;
   for(int zi=0; zi<img->dimz; zi++)
