@@ -425,6 +425,7 @@ extern int strTokenNCpy(
 );
 extern char *strTokenDup(const char *s1, const char *s2, int *next);
 extern int strChrCount(const char *str1, const char *str2);
+extern int strUppercaseCount(const char *s);
 extern void strReplaceChar(char *str, char c1, char c2);
 //#ifndef HAVE_STRNLEN
 extern size_t strnlen(const char *s, size_t n);
@@ -438,6 +439,8 @@ extern size_t strlcpy(char *dst, const char *src, size_t dstsize);
 extern char *strcasestr(const char *haystack, const char *needle); // still missing in MinGW GCC
 extern int strncpyCleanSpaces(char *s1, const char *s2, int maxlen);
 extern int strCleanSpaces(char *s);
+extern char *strEncodeForXML(const char *s);
+extern void strCleanForXML(char *s);
 /*****************************************************************************/
 
 /*****************************************************************************/
