@@ -23,7 +23,7 @@
     2) if x[0]>0, y[0]>0 and x[0]<=x[1]-x[0], then an imaginary line is drawn
        from (0,0) to (x[0],y[0]).
   @return Non-zero in case of an error.
-  @sa finterpolate, integrate, petintegrate, petintegral
+  @sa finterpolate, integrate, petintegrate, petintegral, dftTimeIntegral
 */
 int interpolate(
   /** Input data x (time) values */
