@@ -794,7 +794,7 @@ extern int qrLH(
 extern int runs_test(
   double *data1, double *data2, int N, double alpha, double *p
 );
-extern void residuals(
+extern int residuals(
   double *d1, double *d2, int Nr, int *Rnr, int *Nminus, int *Nplus
 );
 extern int mrl_between_tacs(
