@@ -1,6 +1,6 @@
 #!/bin/bash
 #: Title      : test_tactime
-#: Date       : 2019-10-01
+#: Date       : 2022-03-15
 #: Author     : "Vesa Oikonen" <vesa.oikonen@utu.fi>
 #: Options    : None
 
@@ -516,6 +516,40 @@ printf "\n passed. \n\n"
 
 
 
+printf "\n 4.1.0 \n"
+printf " Test case 1: Move to remove gap. \n"
+printf " Test case 2: PMOD BLD file format. \n"
+printf " Expected result: Correct data saved. \n\n"
+
+$PROGRAM blood.bld -2.5 temp.bld
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+
+rm -f output.bld
+$PROGRAM blood.bld gap output.bld
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -abs=0.01 -rel=0.01 temp.bld output.bld
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+
+printf "\n 4.1.1 \n"
+printf " Test case 1: Move to start at the peak. \n"
+printf " Test case 2: PMOD TAC file format. \n"
+printf " Expected result: Correct data saved. \n\n"
+
+$PROGRAM tissue.tac +3 temp.tac
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+
+rm -f output.tac
+$PROGRAM temp.tac GAP output.tac
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n ok \n"
+tacmatch -abs=0.01 -rel=0.01 tissue.tac output.tac
+if [ $? -ne 0 ] ; then printf "Failed!\n" ; exit 1 ; fi
+printf "\n passed. \n\n"
+
+
 printf "\n===================================================================\n"
 
 printf "\n 5.0.0 \n"
